package cli

import (
	"fmt"
	"strings"

	"git.akyoto.dev/cli/q/src/build"
	"git.akyoto.dev/cli/q/src/build/config"
)

// Build builds an executable.
func Build(args []string) int {
	b := build.New()
	writeExecutable := true

	for i := 0; i < len(args); i++ {
		switch args[i] {
		case "--dry":
			writeExecutable = false

		case "--verbose", "-v":
			config.Verbose = true

		default:
			if strings.HasPrefix(args[i], "-") {
				fmt.Printf("Unknown parameter: %s\n", args[i])
				return 2
			}

			b.Files = append(b.Files, args[i])
		}
	}

	if len(b.Files) == 0 {
		b.Files = append(b.Files, ".")
	}

	result, err := b.Run()

	if err != nil {
		fmt.Println(err)
		return 1
	}

	if !writeExecutable {
		return 0
	}

	path := b.Executable()
	code, data := build.Finalize(result)
	err = build.Write(path, code, data)

	if err != nil {
		fmt.Println(err)
		return 1
	}

	return 0
}
